Reporting Bugs
==============

To report bugs on the Checkbox project you will need a launchpad account. You
may find `instructions on how to create one
<https://help.launchpad.net/YourAccount/NewAccount>`_ useful. Once you have an
account you can `report bugs
<https://bugs.launchpad.net/checkbox-project/+filebug>`_.
